import matplotlib.pyplot as plt

def plotar_dados_acao(dados):
    plt.figure(figsize=(10, 5))
    plt.plot(dados['data'], dados['preco_fechamento'], marker='o')
    plt.title('Preço de Fechamento da Ação')
    plt.xlabel('Data')
    plt.ylabel('Preço de Fechamento')
    plt.grid(True)
    plt.show()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='investimentpy',
    version='1.0.2',
    packages=find_packages(),
    description='Uma biblioteca para análise de investimentos',
    author='Thiago S Adriano',
    author_email='prof.thiagoadriano@gmail.com',
    url='https://github.com/tadrianonet/investimentpy',  
    license='MIT',  
    long_description=long_description,
    long_description_content_type='text/markdown' 
)


# investpy/dados.py
import pandas as pd
import requests

def obter_dados_acao(ticker, api_key):
    base_url = 'https://www.alphavantage.co/query'
    params = {
        'function': 'TIME_SERIES_DAILY',
        'symbol': ticker,
        'apikey': api_key,
        'datatype': 'json'
    }
    response = requests.get(base_url, params=params)
    data = response.json()

    if 'Time Series (Daily)' not in data:
        raise ValueError("Erro ao obter dados da API")

    time_series = data['Time Series (Daily)']
    dates = []
    close_prices = []

    for date, values in time_series.items():
        dates.append(date)
        close_prices.append(float(values['4. close']))

    df = pd.DataFrame({
        'data': pd.to_datetime(dates),
        'preco_fechamento': close_prices
    })

    df.sort_values('data', inplace=True)
    return df
